pub enum FlatlandFactoryError {
InvalidArgs,
Internal,
// some variants omitted
}Expand description
An error that can occur when using [fuchsia.ui.composition/FlatlandFactory.CreateFlatland].
Variants
InvalidArgs
Client provided an invalid configuration, so no Flatland session could be created.
Internal
The server was unable to establish the Flatland session for an unspecified reason that is not the client’s fault.
Implementations
Sourceimpl FlatlandFactoryError
impl FlatlandFactoryError
pub fn from_primitive(prim: u32) -> Option<FlatlandFactoryError>
pub fn from_primitive_allow_unknown(prim: u32) -> FlatlandFactoryError
pub fn unknown() -> FlatlandFactoryError
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool