pub enum FlatlandFactoryRequest {
CreateFlatland {
server_end: ServerEnd<FlatlandMarker>,
config: FlatlandConfig,
responder: FlatlandFactoryCreateFlatlandResponder,
},
}Expand description
Factory protocol for spawning regular (untrusted) Flatland sessions.
Variants
CreateFlatland
Creates a new Flatland session with the specified configuration.
Clients should optimistically assume connection success and immediately begin pipelining
[fuchsia.ui.composition/Flatland] requests without waiting for this method to return.
If session creation fails, the [fuchsia.ui.composition/FlatlandFactory] server closes the
Flatland session channel and returns a [fuchsia.ui.composition/FlatlandFactoryError].
Clients should asynchronously handle this failure and discard their Flatland client
endpoint.
Error
Returns a FlatlandFactoryError if the operation fails.
Fields

server_end: ServerEnd<FlatlandMarker>
config: FlatlandConfig
responder: FlatlandFactoryCreateFlatlandResponderImplementations
Sourceimpl FlatlandFactoryRequest
impl FlatlandFactoryRequest
pub fn into_create_flatland( self, ) -> Option<(ServerEnd<FlatlandMarker>, FlatlandConfig, FlatlandFactoryCreateFlatlandResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL