pub enum SignalFence {
Basic(NullableHandle),
Timestamp(Counter),
}Expand description
A fence that will be signaled by Scenic when some condition becomes true. For more details, refer to the method the fence appears in.
Variants
Basic(NullableHandle)
A basic handle (e.g., EVENT or EVENTPAIR).
Timestamp(Counter)
Before Scenic signals the fence, it will write the timestamp of the corresponding event into the counter.
Implementations