pub enum TransformContent {
LayerStack(LayerStackId),
Viewport(ViewportId),
}Expand description
Content that can be attached to a Transform when Flatland2 is enabled.
This union defines the types of content that can be attached to a Transform
using [Flatland.SetTransformContent].
Variants
LayerStack(LayerStackId)
Viewport(ViewportId)
Implementations