TrustedFlatlandRequest

Enum TrustedFlatlandRequest 

pub enum TrustedFlatlandRequest {
    ReleaseImageImmediately {
        image_id: ContentId,
        control_handle: TrustedFlatlandControlHandle,
    },
    ReleaseImageImmediately2 {
        image_id: ImageId,
        control_handle: TrustedFlatlandControlHandle,
    },
}
A privileged protocol for trusted Flatland sessions that require special capabilities.

This protocol is composed into the [Flatland] protocol. Methods in this protocol are only available if the Flatland session was created via [TrustedFlatlandFactory].

Variants



ReleaseImageImmediately

Releases an image immediately, without waiting for the next present.

Fields

image_id: ContentId


ReleaseImageImmediately2

Releases an Image immediately, without waiting for the next present. This is a trusted memory-eviction path.

The Image is forcibly unbound from any Layers that currently reference it. Those Layers behave as if their image was simply never set (they are invisible, but retain their image properties) until their next SetLayerImage().

Any pending release fences for the evicted Image’s bindings will signal at the earliest safe point.

This method is only available if Flatland2 is enabled and the session is trusted.

Fields

image_id: ImageId

Implementations