pub enum WaitFence {
Basic(NullableHandle),
Timestamp(Counter),
}Expand description
A fence that will be signaled when the associated resource is ready for Scenic to use. For context-specific usage info, refer to the method the fence appears in.
Variants
Basic(NullableHandle)
A basic handle (e.g., EVENT or EVENTPAIR).
Timestamp(Counter)
At the time the fence is signalled, the timestamp of the corresponding event will have been written into the counter.
Implementations