pub struct Flatland2CreateImage2Request {
pub image_id: ImageId,
pub import_token: BufferCollectionImportToken,
pub vmo_index: u32,
pub properties: ImageProperties,
}Fields
image_id: ImageIdimport_token: BufferCollectionImportTokenvmo_index: u32properties: ImagePropertiesTrait Implementations
Sourceimpl Debug for Flatland2CreateImage2Request
impl Debug for Flatland2CreateImage2Request
Sourceimpl Decode<Flatland2CreateImage2Request, DefaultFuchsiaResourceDialect> for Flatland2CreateImage2Request
impl Decode<Flatland2CreateImage2Request, DefaultFuchsiaResourceDialect> for Flatland2CreateImage2Request
Sourceimpl Encode<Flatland2CreateImage2Request, DefaultFuchsiaResourceDialect> for &mut Flatland2CreateImage2Request
impl Encode<Flatland2CreateImage2Request, DefaultFuchsiaResourceDialect> for &mut Flatland2CreateImage2Request
Sourceimpl<T0: Encode<ImageId, DefaultFuchsiaResourceDialect>, T1: Encode<BufferCollectionImportToken, DefaultFuchsiaResourceDialect>, T2: Encode<u32, DefaultFuchsiaResourceDialect>, T3: Encode<ImageProperties, DefaultFuchsiaResourceDialect>> Encode<Flatland2CreateImage2Request, DefaultFuchsiaResourceDialect> for (T0, T1, T2, T3)
impl<T0: Encode<ImageId, DefaultFuchsiaResourceDialect>, T1: Encode<BufferCollectionImportToken, DefaultFuchsiaResourceDialect>, T2: Encode<u32, DefaultFuchsiaResourceDialect>, T3: Encode<ImageProperties, DefaultFuchsiaResourceDialect>> Encode<Flatland2CreateImage2Request, DefaultFuchsiaResourceDialect> for (T0, T1, T2, T3)
Sourceimpl ResourceTypeMarker for Flatland2CreateImage2Request
impl ResourceTypeMarker for Flatland2CreateImage2Request
Sourcetype Borrowed<'a> = &'a mut Flatland2CreateImage2Request
type Borrowed<'a> = &'a mut Flatland2CreateImage2Request
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for Flatland2CreateImage2Request
impl StructuralPartialEq for Flatland2CreateImage2Request
Sourceimpl TypeMarker for Flatland2CreateImage2Request
impl TypeMarker for Flatland2CreateImage2Request
Sourcetype Owned = Flatland2CreateImage2Request
type Owned = Flatland2CreateImage2Request
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for Flatland2CreateImage2Request
impl RefUnwindSafe for Flatland2CreateImage2Request
impl Send for Flatland2CreateImage2Request
impl Sync for Flatland2CreateImage2Request
impl Unpin for Flatland2CreateImage2Request
impl UnsafeUnpin for Flatland2CreateImage2Request
impl UnwindSafe for Flatland2CreateImage2Request