#[repr(C)]pub struct Flatland2CreateLayerStackRequest {
pub stack_id: LayerStackId,
}Fields
stack_id: LayerStackIdTrait Implementations
Sourceimpl Clone for Flatland2CreateLayerStackRequest
impl Clone for Flatland2CreateLayerStackRequest
Sourcefn clone(&self) -> Flatland2CreateLayerStackRequest
fn clone(&self) -> Flatland2CreateLayerStackRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Flatland2CreateLayerStackRequest
Sourceimpl<D> Decode<Flatland2CreateLayerStackRequest, D> for Flatland2CreateLayerStackRequestwhere
D: ResourceDialect,
impl<D> Decode<Flatland2CreateLayerStackRequest, D> for Flatland2CreateLayerStackRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> Flatland2CreateLayerStackRequest
fn new_empty() -> Flatland2CreateLayerStackRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<Flatland2CreateLayerStackRequest, D> for &Flatland2CreateLayerStackRequestwhere
D: ResourceDialect,
impl<D> Encode<Flatland2CreateLayerStackRequest, D> for &Flatland2CreateLayerStackRequestwhere
D: ResourceDialect,
impl Eq for Flatland2CreateLayerStackRequest
Sourceimpl Ord for Flatland2CreateLayerStackRequest
impl Ord for Flatland2CreateLayerStackRequest
Sourcefn cmp(&self, other: &Flatland2CreateLayerStackRequest) -> Ordering
fn cmp(&self, other: &Flatland2CreateLayerStackRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Flatland2CreateLayerStackRequest
impl PartialOrd for Flatland2CreateLayerStackRequest
impl Persistable for Flatland2CreateLayerStackRequest
impl StructuralPartialEq for Flatland2CreateLayerStackRequest
Sourceimpl TypeMarker for Flatland2CreateLayerStackRequest
impl TypeMarker for Flatland2CreateLayerStackRequest
Sourcetype Owned = Flatland2CreateLayerStackRequest
type Owned = Flatland2CreateLayerStackRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Flatland2CreateLayerStackRequest
impl ValueTypeMarker for Flatland2CreateLayerStackRequest
Sourcetype Borrowed<'a> = &'a Flatland2CreateLayerStackRequest
type Borrowed<'a> = &'a Flatland2CreateLayerStackRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Flatland2CreateLayerStackRequest as TypeMarker>::Owned,
) -> <Flatland2CreateLayerStackRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Flatland2CreateLayerStackRequest as TypeMarker>::Owned, ) -> <Flatland2CreateLayerStackRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for Flatland2CreateLayerStackRequest
impl RefUnwindSafe for Flatland2CreateLayerStackRequest
impl Send for Flatland2CreateLayerStackRequest
impl Sync for Flatland2CreateLayerStackRequest
impl Unpin for Flatland2CreateLayerStackRequest
impl UnsafeUnpin for Flatland2CreateLayerStackRequest
impl UnwindSafe for Flatland2CreateLayerStackRequest