#[repr(C)]pub struct Flatland2ReleaseImage2Request {
pub image_id: ImageId,
}Fields
image_id: ImageIdTrait Implementations
Sourceimpl Clone for Flatland2ReleaseImage2Request
impl Clone for Flatland2ReleaseImage2Request
Sourcefn clone(&self) -> Flatland2ReleaseImage2Request
fn clone(&self) -> Flatland2ReleaseImage2Request
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Flatland2ReleaseImage2Request
Sourceimpl<D> Decode<Flatland2ReleaseImage2Request, D> for Flatland2ReleaseImage2Requestwhere
D: ResourceDialect,
impl<D> Decode<Flatland2ReleaseImage2Request, D> for Flatland2ReleaseImage2Requestwhere
D: ResourceDialect,
Sourcefn new_empty() -> Flatland2ReleaseImage2Request
fn new_empty() -> Flatland2ReleaseImage2Request
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<Flatland2ReleaseImage2Request, D> for &Flatland2ReleaseImage2Requestwhere
D: ResourceDialect,
impl<D> Encode<Flatland2ReleaseImage2Request, D> for &Flatland2ReleaseImage2Requestwhere
D: ResourceDialect,
impl Eq for Flatland2ReleaseImage2Request
Sourceimpl Hash for Flatland2ReleaseImage2Request
impl Hash for Flatland2ReleaseImage2Request
Sourceimpl Ord for Flatland2ReleaseImage2Request
impl Ord for Flatland2ReleaseImage2Request
Sourcefn cmp(&self, other: &Flatland2ReleaseImage2Request) -> Ordering
fn cmp(&self, other: &Flatland2ReleaseImage2Request) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Flatland2ReleaseImage2Request
impl PartialOrd for Flatland2ReleaseImage2Request
impl Persistable for Flatland2ReleaseImage2Request
impl StructuralPartialEq for Flatland2ReleaseImage2Request
Sourceimpl TypeMarker for Flatland2ReleaseImage2Request
impl TypeMarker for Flatland2ReleaseImage2Request
Sourcetype Owned = Flatland2ReleaseImage2Request
type Owned = Flatland2ReleaseImage2Request
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Flatland2ReleaseImage2Request
impl ValueTypeMarker for Flatland2ReleaseImage2Request
Sourcetype Borrowed<'a> = &'a Flatland2ReleaseImage2Request
type Borrowed<'a> = &'a Flatland2ReleaseImage2Request
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Flatland2ReleaseImage2Request as TypeMarker>::Owned,
) -> <Flatland2ReleaseImage2Request as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Flatland2ReleaseImage2Request as TypeMarker>::Owned, ) -> <Flatland2ReleaseImage2Request as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for Flatland2ReleaseImage2Request
impl RefUnwindSafe for Flatland2ReleaseImage2Request
impl Send for Flatland2ReleaseImage2Request
impl Sync for Flatland2ReleaseImage2Request
impl Unpin for Flatland2ReleaseImage2Request
impl UnsafeUnpin for Flatland2ReleaseImage2Request
impl UnwindSafe for Flatland2ReleaseImage2Request