#[repr(C)]pub struct Flatland2ReleaseLayerStackRequest {
pub stack_id: LayerStackId,
}Fields
stack_id: LayerStackIdTrait Implementations
Sourceimpl Clone for Flatland2ReleaseLayerStackRequest
impl Clone for Flatland2ReleaseLayerStackRequest
Sourcefn clone(&self) -> Flatland2ReleaseLayerStackRequest
fn clone(&self) -> Flatland2ReleaseLayerStackRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Flatland2ReleaseLayerStackRequest
Sourceimpl<D> Decode<Flatland2ReleaseLayerStackRequest, D> for Flatland2ReleaseLayerStackRequestwhere
D: ResourceDialect,
impl<D> Decode<Flatland2ReleaseLayerStackRequest, D> for Flatland2ReleaseLayerStackRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> Flatland2ReleaseLayerStackRequest
fn new_empty() -> Flatland2ReleaseLayerStackRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<Flatland2ReleaseLayerStackRequest, D> for &Flatland2ReleaseLayerStackRequestwhere
D: ResourceDialect,
impl<D> Encode<Flatland2ReleaseLayerStackRequest, D> for &Flatland2ReleaseLayerStackRequestwhere
D: ResourceDialect,
impl Eq for Flatland2ReleaseLayerStackRequest
Sourceimpl Ord for Flatland2ReleaseLayerStackRequest
impl Ord for Flatland2ReleaseLayerStackRequest
Sourcefn cmp(&self, other: &Flatland2ReleaseLayerStackRequest) -> Ordering
fn cmp(&self, other: &Flatland2ReleaseLayerStackRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Flatland2ReleaseLayerStackRequest
impl PartialOrd for Flatland2ReleaseLayerStackRequest
impl Persistable for Flatland2ReleaseLayerStackRequest
impl StructuralPartialEq for Flatland2ReleaseLayerStackRequest
Sourceimpl TypeMarker for Flatland2ReleaseLayerStackRequest
impl TypeMarker for Flatland2ReleaseLayerStackRequest
Sourcetype Owned = Flatland2ReleaseLayerStackRequest
type Owned = Flatland2ReleaseLayerStackRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Flatland2ReleaseLayerStackRequest
impl ValueTypeMarker for Flatland2ReleaseLayerStackRequest
Sourcetype Borrowed<'a> = &'a Flatland2ReleaseLayerStackRequest
type Borrowed<'a> = &'a Flatland2ReleaseLayerStackRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Flatland2ReleaseLayerStackRequest as TypeMarker>::Owned,
) -> <Flatland2ReleaseLayerStackRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Flatland2ReleaseLayerStackRequest as TypeMarker>::Owned, ) -> <Flatland2ReleaseLayerStackRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for Flatland2ReleaseLayerStackRequest
impl RefUnwindSafe for Flatland2ReleaseLayerStackRequest
impl Send for Flatland2ReleaseLayerStackRequest
impl Sync for Flatland2ReleaseLayerStackRequest
impl Unpin for Flatland2ReleaseLayerStackRequest
impl UnsafeUnpin for Flatland2ReleaseLayerStackRequest
impl UnwindSafe for Flatland2ReleaseLayerStackRequest