pub struct Flatland2ReleaseViewport2Response {
pub token: ViewportCreationToken,
}Fields
token: ViewportCreationTokenTrait Implementations
Sourceimpl Decode<Flatland2ReleaseViewport2Response, DefaultFuchsiaResourceDialect> for Flatland2ReleaseViewport2Response
impl Decode<Flatland2ReleaseViewport2Response, DefaultFuchsiaResourceDialect> for Flatland2ReleaseViewport2Response
Sourceimpl Encode<Flatland2ReleaseViewport2Response, DefaultFuchsiaResourceDialect> for &mut Flatland2ReleaseViewport2Response
impl Encode<Flatland2ReleaseViewport2Response, DefaultFuchsiaResourceDialect> for &mut Flatland2ReleaseViewport2Response
Sourceimpl<T0: Encode<ViewportCreationToken, DefaultFuchsiaResourceDialect>> Encode<Flatland2ReleaseViewport2Response, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<ViewportCreationToken, DefaultFuchsiaResourceDialect>> Encode<Flatland2ReleaseViewport2Response, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl ResourceTypeMarker for Flatland2ReleaseViewport2Response
impl ResourceTypeMarker for Flatland2ReleaseViewport2Response
Sourcetype Borrowed<'a> = &'a mut Flatland2ReleaseViewport2Response
type Borrowed<'a> = &'a mut Flatland2ReleaseViewport2Response
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for Flatland2ReleaseViewport2Response
impl StructuralPartialEq for Flatland2ReleaseViewport2Response
Sourceimpl TypeMarker for Flatland2ReleaseViewport2Response
impl TypeMarker for Flatland2ReleaseViewport2Response
Sourcetype Owned = Flatland2ReleaseViewport2Response
type Owned = Flatland2ReleaseViewport2Response
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for Flatland2ReleaseViewport2Response
impl RefUnwindSafe for Flatland2ReleaseViewport2Response
impl Send for Flatland2ReleaseViewport2Response
impl Sync for Flatland2ReleaseViewport2Response
impl Unpin for Flatland2ReleaseViewport2Response
impl UnsafeUnpin for Flatland2ReleaseViewport2Response
impl UnwindSafe for Flatland2ReleaseViewport2Response