pub struct Flatland2SetLayerPropertiesRequest {
pub layer_id: LayerId,
pub properties: LayerProperties,
}Fields
layer_id: LayerIdproperties: LayerPropertiesTrait Implementations
Sourceimpl Clone for Flatland2SetLayerPropertiesRequest
impl Clone for Flatland2SetLayerPropertiesRequest
Sourcefn clone(&self) -> Flatland2SetLayerPropertiesRequest
fn clone(&self) -> Flatland2SetLayerPropertiesRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<Flatland2SetLayerPropertiesRequest, D> for Flatland2SetLayerPropertiesRequestwhere
D: ResourceDialect,
impl<D> Decode<Flatland2SetLayerPropertiesRequest, D> for Flatland2SetLayerPropertiesRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> Flatland2SetLayerPropertiesRequest
fn new_empty() -> Flatland2SetLayerPropertiesRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<Flatland2SetLayerPropertiesRequest, D> for &Flatland2SetLayerPropertiesRequestwhere
D: ResourceDialect,
impl<D> Encode<Flatland2SetLayerPropertiesRequest, D> for &Flatland2SetLayerPropertiesRequestwhere
D: ResourceDialect,
impl Persistable for Flatland2SetLayerPropertiesRequest
impl StructuralPartialEq for Flatland2SetLayerPropertiesRequest
Sourceimpl TypeMarker for Flatland2SetLayerPropertiesRequest
impl TypeMarker for Flatland2SetLayerPropertiesRequest
Sourcetype Owned = Flatland2SetLayerPropertiesRequest
type Owned = Flatland2SetLayerPropertiesRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Flatland2SetLayerPropertiesRequest
impl ValueTypeMarker for Flatland2SetLayerPropertiesRequest
Sourcetype Borrowed<'a> = &'a Flatland2SetLayerPropertiesRequest
type Borrowed<'a> = &'a Flatland2SetLayerPropertiesRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Flatland2SetLayerPropertiesRequest as TypeMarker>::Owned,
) -> <Flatland2SetLayerPropertiesRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Flatland2SetLayerPropertiesRequest as TypeMarker>::Owned, ) -> <Flatland2SetLayerPropertiesRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for Flatland2SetLayerPropertiesRequest
impl RefUnwindSafe for Flatland2SetLayerPropertiesRequest
impl Send for Flatland2SetLayerPropertiesRequest
impl Sync for Flatland2SetLayerPropertiesRequest
impl Unpin for Flatland2SetLayerPropertiesRequest
impl UnsafeUnpin for Flatland2SetLayerPropertiesRequest
impl UnwindSafe for Flatland2SetLayerPropertiesRequest