pub struct Flatland2SetStackLayersRequest {
pub stack_id: LayerStackId,
pub layers: Vec<LayerId>,
}Fields
stack_id: LayerStackIdlayers: Vec<LayerId>Trait Implementations
Sourceimpl Clone for Flatland2SetStackLayersRequest
impl Clone for Flatland2SetStackLayersRequest
Sourcefn clone(&self) -> Flatland2SetStackLayersRequest
fn clone(&self) -> Flatland2SetStackLayersRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<Flatland2SetStackLayersRequest, D> for Flatland2SetStackLayersRequestwhere
D: ResourceDialect,
impl<D> Decode<Flatland2SetStackLayersRequest, D> for Flatland2SetStackLayersRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> Flatland2SetStackLayersRequest
fn new_empty() -> Flatland2SetStackLayersRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<Flatland2SetStackLayersRequest, D> for &Flatland2SetStackLayersRequestwhere
D: ResourceDialect,
impl<D> Encode<Flatland2SetStackLayersRequest, D> for &Flatland2SetStackLayersRequestwhere
D: ResourceDialect,
impl Eq for Flatland2SetStackLayersRequest
Sourceimpl Ord for Flatland2SetStackLayersRequest
impl Ord for Flatland2SetStackLayersRequest
Sourcefn cmp(&self, other: &Flatland2SetStackLayersRequest) -> Ordering
fn cmp(&self, other: &Flatland2SetStackLayersRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for Flatland2SetStackLayersRequest
impl PartialOrd for Flatland2SetStackLayersRequest
impl Persistable for Flatland2SetStackLayersRequest
impl StructuralPartialEq for Flatland2SetStackLayersRequest
Sourceimpl TypeMarker for Flatland2SetStackLayersRequest
impl TypeMarker for Flatland2SetStackLayersRequest
Sourcetype Owned = Flatland2SetStackLayersRequest
type Owned = Flatland2SetStackLayersRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Flatland2SetStackLayersRequest
impl ValueTypeMarker for Flatland2SetStackLayersRequest
Sourcetype Borrowed<'a> = &'a Flatland2SetStackLayersRequest
type Borrowed<'a> = &'a Flatland2SetStackLayersRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Flatland2SetStackLayersRequest as TypeMarker>::Owned,
) -> <Flatland2SetStackLayersRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Flatland2SetStackLayersRequest as TypeMarker>::Owned, ) -> <Flatland2SetStackLayersRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for Flatland2SetStackLayersRequest
impl RefUnwindSafe for Flatland2SetStackLayersRequest
impl Send for Flatland2SetStackLayersRequest
impl Sync for Flatland2SetStackLayersRequest
impl Unpin for Flatland2SetStackLayersRequest
impl UnsafeUnpin for Flatland2SetStackLayersRequest
impl UnwindSafe for Flatland2SetStackLayersRequest