pub struct FlatlandFactoryMarker;Trait Implementations
Sourceimpl Clone for FlatlandFactoryMarker
impl Clone for FlatlandFactoryMarker
Sourcefn clone(&self) -> FlatlandFactoryMarker
fn clone(&self) -> FlatlandFactoryMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FlatlandFactoryMarker
Sourceimpl Debug for FlatlandFactoryMarker
impl Debug for FlatlandFactoryMarker
Sourceimpl DiscoverableProtocolMarker for FlatlandFactoryMarker
impl DiscoverableProtocolMarker for FlatlandFactoryMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for FlatlandFactoryMarker
Sourceimpl Hash for FlatlandFactoryMarker
impl Hash for FlatlandFactoryMarker
Sourceimpl Ord for FlatlandFactoryMarker
impl Ord for FlatlandFactoryMarker
Sourcefn cmp(&self, other: &FlatlandFactoryMarker) -> Ordering
fn cmp(&self, other: &FlatlandFactoryMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for FlatlandFactoryMarker
impl PartialEq for FlatlandFactoryMarker
Sourceimpl PartialOrd for FlatlandFactoryMarker
impl PartialOrd for FlatlandFactoryMarker
Sourceimpl ProtocolMarker for FlatlandFactoryMarker
impl ProtocolMarker for FlatlandFactoryMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.ui.composition.FlatlandFactory"
const DEBUG_NAME: &'static str = "fuchsia.ui.composition.FlatlandFactory"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = FlatlandFactoryProxy
type Proxy = FlatlandFactoryProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = FlatlandFactoryRequestStream
type RequestStream = FlatlandFactoryRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = FlatlandFactorySynchronousProxy
type SynchronousProxy = FlatlandFactorySynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for FlatlandFactoryMarker