pub struct FlatlandFactorySynchronousProxy { /* private fields */ }Implementations
Sourceimpl FlatlandFactorySynchronousProxy
impl FlatlandFactorySynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<FlatlandFactoryEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<FlatlandFactoryEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn create_flatland(
&self,
server_end: ServerEnd<FlatlandMarker>,
config: &FlatlandConfig,
___deadline: MonotonicInstant,
) -> Result<FlatlandFactoryCreateFlatlandResult, Error>
pub fn create_flatland( &self, server_end: ServerEnd<FlatlandMarker>, config: &FlatlandConfig, ___deadline: MonotonicInstant, ) -> Result<FlatlandFactoryCreateFlatlandResult, Error>
Creates a new Flatland session with the specified configuration.
Clients should optimistically assume connection success and immediately begin pipelining
[fuchsia.ui.composition/Flatland] requests without waiting for this method to return.
If session creation fails, the [fuchsia.ui.composition/FlatlandFactory] server closes the
Flatland session channel and returns a [fuchsia.ui.composition/FlatlandFactoryError].
Clients should asynchronously handle this failure and discard their Flatland client
endpoint.
Error
Returns a FlatlandFactoryError if the operation fails.