pub struct FlatlandReleaseViewport2Responder { /* private fields */ }Implementations
Sourceimpl FlatlandReleaseViewport2Responder
impl FlatlandReleaseViewport2Responder
Sourcepub fn send(self, token: ViewportCreationToken) -> Result<(), Error>
pub fn send(self, token: ViewportCreationToken) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
token: ViewportCreationToken,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, token: ViewportCreationToken, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.