pub struct FlipThenRotate(/* private fields */);Expand description
Bitset which supports all permutations of flips and rotations. Flips (if any) are performed first, followed by rotation (if any).
Implementations
Sourceimpl FlipThenRotate
impl FlipThenRotate
Sourcepub const FLIP_H: FlipThenRotate
pub const FLIP_H: FlipThenRotate
Flip the image horizontally (across the Y-axis).
Sourcepub const FLIP_V: FlipThenRotate
pub const FLIP_V: FlipThenRotate
Flip the image vertically (across the X-axis).
Sourcepub const ROTATE_90: FlipThenRotate
pub const ROTATE_90: FlipThenRotate
Rotate the image 90 degrees clockwise.
Sourceimpl FlipThenRotate
impl FlipThenRotate
Sourcepub const fn empty() -> FlipThenRotate
pub const fn empty() -> FlipThenRotate
Get a flags value with all bits unset.
Sourcepub const fn all() -> FlipThenRotate
pub const fn all() -> FlipThenRotate
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<FlipThenRotate>
pub const fn from_bits(bits: u8) -> Option<FlipThenRotate>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> FlipThenRotate
pub const fn from_bits_truncate(bits: u8) -> FlipThenRotate
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> FlipThenRotate
pub const fn from_bits_retain(bits: u8) -> FlipThenRotate
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<FlipThenRotate>
pub fn from_name(name: &str) -> Option<FlipThenRotate>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: FlipThenRotate) -> bool
pub const fn intersects(&self, other: FlipThenRotate) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: FlipThenRotate) -> bool
pub const fn contains(&self, other: FlipThenRotate) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: FlipThenRotate)
pub fn insert(&mut self, other: FlipThenRotate)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: FlipThenRotate)
pub fn remove(&mut self, other: FlipThenRotate)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: FlipThenRotate)
pub fn toggle(&mut self, other: FlipThenRotate)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: FlipThenRotate, value: bool)
pub fn set(&mut self, other: FlipThenRotate, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: FlipThenRotate) -> FlipThenRotate
pub const fn intersection(self, other: FlipThenRotate) -> FlipThenRotate
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: FlipThenRotate) -> FlipThenRotate
pub const fn union(self, other: FlipThenRotate) -> FlipThenRotate
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: FlipThenRotate) -> FlipThenRotate
pub const fn difference(self, other: FlipThenRotate) -> FlipThenRotate
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: FlipThenRotate) -> FlipThenRotate
pub const fn symmetric_difference(self, other: FlipThenRotate) -> FlipThenRotate
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> FlipThenRotate
pub const fn complement(self) -> FlipThenRotate
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl FlipThenRotate
impl FlipThenRotate
Sourcepub const fn iter(&self) -> Iter<FlipThenRotate> ⓘ
pub const fn iter(&self) -> Iter<FlipThenRotate> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FlipThenRotate> ⓘ
pub const fn iter_names(&self) -> IterNames<FlipThenRotate> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.