#[repr(C)]pub struct ImageId {
pub value: u64,
}Expand description
A user-defined identifier for a particular image created with [Flatland.CreateImage2].
Zero is never a valid ImageId; the shared identifier rules documented on
LayerId also apply.
Fields
value: u64Trait Implementations
impl Copy for ImageId
Sourceimpl<D> Decode<ImageId, D> for ImageIdwhere
D: ResourceDialect,
impl<D> Decode<ImageId, D> for ImageIdwhere
D: ResourceDialect,
impl Eq for ImageId
Sourceimpl Ord for ImageId
impl Ord for ImageId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for ImageId
impl PartialOrd for ImageId
impl Persistable for ImageId
impl StructuralPartialEq for ImageId
Sourceimpl TypeMarker for ImageId
impl TypeMarker for ImageId
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ImageId
impl ValueTypeMarker for ImageId
Sourcetype Borrowed<'a> = &'a ImageId
type Borrowed<'a> = &'a ImageId
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ImageId as TypeMarker>::Owned,
) -> <ImageId as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ImageId as TypeMarker>::Owned, ) -> <ImageId as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for ImageId
impl RefUnwindSafe for ImageId
impl Send for ImageId
impl Sync for ImageId
impl Unpin for ImageId
impl UnsafeUnpin for ImageId
impl UnwindSafe for ImageId