#[repr(C)]pub struct LayerStackId {
pub value: u64,
}Expand description
A user-defined identifier for a particular layer stack created with [Flatland.CreateLayerStack].
Zero is never a valid LayerStackId; the shared identifier rules documented on
LayerId also apply.
Fields
value: u64Trait Implementations
Sourceimpl Clone for LayerStackId
impl Clone for LayerStackId
Sourcefn clone(&self) -> LayerStackId
fn clone(&self) -> LayerStackId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LayerStackId
Sourceimpl Debug for LayerStackId
impl Debug for LayerStackId
Sourceimpl<D> Decode<LayerStackId, D> for LayerStackIdwhere
D: ResourceDialect,
impl<D> Decode<LayerStackId, D> for LayerStackIdwhere
D: ResourceDialect,
Sourcefn new_empty() -> LayerStackId
fn new_empty() -> LayerStackId
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<LayerStackId, D> for &LayerStackIdwhere
D: ResourceDialect,
impl<D> Encode<LayerStackId, D> for &LayerStackIdwhere
D: ResourceDialect,
impl Eq for LayerStackId
Sourceimpl Hash for LayerStackId
impl Hash for LayerStackId
Sourceimpl Ord for LayerStackId
impl Ord for LayerStackId
Sourcefn cmp(&self, other: &LayerStackId) -> Ordering
fn cmp(&self, other: &LayerStackId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for LayerStackId
impl PartialEq for LayerStackId
Sourceimpl PartialOrd for LayerStackId
impl PartialOrd for LayerStackId
impl Persistable for LayerStackId
impl StructuralPartialEq for LayerStackId
Sourceimpl TypeMarker for LayerStackId
impl TypeMarker for LayerStackId
Sourcetype Owned = LayerStackId
type Owned = LayerStackId
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for LayerStackId
impl ValueTypeMarker for LayerStackId
Sourcetype Borrowed<'a> = &'a LayerStackId
type Borrowed<'a> = &'a LayerStackId
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<LayerStackId as TypeMarker>::Owned,
) -> <LayerStackId as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<LayerStackId as TypeMarker>::Owned, ) -> <LayerStackId as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for LayerStackId
impl RefUnwindSafe for LayerStackId
impl Send for LayerStackId
impl Sync for LayerStackId
impl Unpin for LayerStackId
impl UnsafeUnpin for LayerStackId
impl UnwindSafe for LayerStackId