OnNextFrameBeginValues

Struct OnNextFrameBeginValues 

pub struct OnNextFrameBeginValues {
    pub additional_present_credits: Option<u32>,
    pub future_presentation_infos: Option<Vec<PresentationInfo>>,
    /* private fields */
}
Fields that a client needs in order to produce its next frame, returned in [OnNextFrameBegin]. Each field is guaranteed to be set and contain valid information.

Fields

additional_present_credits: Option<u32>

The number of additional [Present] calls allowed to the client so that they can call [Present] further times. This is a delta in the present credit budget, not the absolute number of present credits.

future_presentation_infos: Option<Vec<PresentationInfo>>

Information about future presentation and latch times that a client may aim for precise scheduling behavior.