pub struct TrustedFlatlandConfig {
pub schedule_asap: Option<bool>,
pub pass_acquire_fences: Option<bool>,
pub skips_present_credits: Option<bool>,
/* private fields */
}Expand description
All arguments are optional; default values will be provided if they are absent.
By default, the resulting Flatland will behave identically to connecting
to the fuchsia.ui.composition.Flatland service instead of connecting via the factory.
Fields
schedule_asap: Option<bool>If true and requested_presentation_time in [fuchsia.ui.composition/Flatland.Present] is
set to 0 or less than or equal to the nearest presentation time, a frame will be scheduled
to be presented as soon as all acquire fences are signaled, instead of waiting for other
clients to present within the same vsync. This allows the caller to decide when to wake up
for preparing a frame.
If requested_presentation_time is set to a value greater than the nearest presentation
time, this flag will have no effect and the wakeup time decision will be made by the
scheduler.
If absent, schedule_asap is false.
pass_acquire_fences: Option<bool>If true, Scenic should pass acquire fences to the drivers for composition HW, instead of waiting for them on CPU. This can improve performance by reducing CPU overhead.
If absent, pass_acquire_fences is false.
skips_present_credits: Option<bool>If true, the client will not utilize Flatland’s built in frame-scheduling mechanism and will ignore present credits, instead relying on their own flow control system.
If absent, skips_present_credits is false.