TrustedFlatlandSynchronousProxy

Struct TrustedFlatlandSynchronousProxy 

pub struct TrustedFlatlandSynchronousProxy { /* private fields */ }

Implementations

Source

impl TrustedFlatlandSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<TrustedFlatlandEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn release_image_immediately( &self, image_id: &ContentId, ) -> Result<(), Error>

Releases an image immediately, without waiting for the next present.

pub fn release_image_immediately2( &self, image_id: &ImageId, ) -> Result<(), Error>

Releases an Image immediately, without waiting for the next present. This is a trusted memory-eviction path.

The Image is forcibly unbound from any Layers that currently reference it. Those Layers behave as if their image was simply never set (they are invisible, but retain their image properties) until their next SetLayerImage().

Any pending release fences for the evicted Image’s bindings will signal at the earliest safe point.

This method is only available if Flatland2 is enabled and the session is trusted.