pub struct TrustedFlatlandProxy { /* private fields */ }Implementations
Sourceimpl TrustedFlatlandProxy
impl TrustedFlatlandProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.ui.composition/TrustedFlatland.
Sourcepub fn take_event_stream(&self) -> TrustedFlatlandEventStream
pub fn take_event_stream(&self) -> TrustedFlatlandEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn release_image_immediately(
&self,
image_id: &ContentId,
) -> Result<(), Error>
pub fn release_image_immediately( &self, image_id: &ContentId, ) -> Result<(), Error>
Releases an image immediately, without waiting for the next present.
Sourcepub fn release_image_immediately2(
&self,
image_id: &ImageId,
) -> Result<(), Error>
pub fn release_image_immediately2( &self, image_id: &ImageId, ) -> Result<(), Error>
Releases an Image immediately, without waiting for the next present. This is a trusted memory-eviction path.
The Image is forcibly unbound from any Layers that currently reference it. Those Layers
behave as if their image was simply never set (they are invisible, but retain their image
properties) until their next SetLayerImage().
Any pending release fences for the evicted Image’s bindings will signal at the earliest safe point.
This method is only available if Flatland2 is enabled and the session is trusted.